@@ -6,14 +6,17 @@ from emannotationschemas.schemas.synapse import BuhmannEcksteinSynapseSchema
 from emannotationschemas.schemas.synapse import NoCleftSynapse
 from emannotationschemas.schemas.bouton_shape import BoutonShape
 from emannotationschemas.schemas.presynaptic_bouton_type import PresynapticBoutonType
-from emannotationschemas.schemas.base import ReferenceAnnotation
+from emannotationschemas.schemas.base import ReferenceAnnotation, ReferenceTagAnnotation
 from emannotationschemas.schemas.functional_coregistration import (
     FunctionalCoregistration,
     FunctionalUnitCoregistration,
-    FunctionalUnitCoregistrationExtended
+    FunctionalUnitCoregistrationExtended,
 )
 from emannotationschemas.schemas.postsynaptic_compartment import PostsynapticCompartment
-from emannotationschemas.schemas.base import FlatSegmentationReferenceSinglePoint
+from emannotationschemas.schemas.base import (
+    FlatSegmentationReferenceSinglePoint,
+    RepresentativePoint,
+)
 from emannotationschemas.schemas.cell_type_local import CellTypeLocal, CellTypeReference
 from emannotationschemas.schemas.bound_text_tag import (
     BoundTagAnnotation,
@@ -42,12 +45,14 @@ from emannotationschemas.schemas.proofreading import (
 from emannotationschemas.schemas.neuropil import FlyNeuropil
 from emannotationschemas.schemas.groups import SimpleGroup
 from emannotationschemas.schemas.fly_cell_types import FlyCellType, FlyCellTypeExt
-from emannotationschemas.schemas.braincircuits import BrainCircuitsBoundTagAnnotationUser
+from emannotationschemas.schemas.braincircuits import (
+    BrainCircuitsBoundTagAnnotationUser,
+)
 
 from emannotationschemas.errors import UnknownAnnotationTypeException
 from emannotationschemas.flatten import create_flattened_schema
 
-__version__ = "5.5.0"
+__version__ = "5.7.0"
 
 type_mapping = {
     "synapse": SynapseSchema,
@@ -61,6 +66,7 @@ type_mapping = {
     "microns_func_unit_coreg": FunctionalUnitCoregistration,
     "func_unit_ext_coreg": FunctionalUnitCoregistrationExtended,
     "simple_reference": ReferenceAnnotation,
+    "reference_tag": ReferenceTagAnnotation,
     "cell_type_local": CellTypeLocal,
     "cell_type_reference": CellTypeReference,
     "nucleus_detection": NucleusDetection,
@@ -82,6 +88,7 @@ type_mapping = {
     "proofreading_boolstatus_user": ProofreadingBoolStatusUser,
     "fly_neuropil": FlyNeuropil,
     "reference_point": FlatSegmentationReferenceSinglePoint,
+    "representative_point": RepresentativePoint,
     "reference_synapse_valid": ValidSynapse,
     "reference_simple_group": SimpleGroup,
     "fly_cell_type": FlyCellType,
