@@ -3,10 +3,7 @@ import marshmallow as mm
 
 def flatten_fields(schema, root=None, sep="_"):
     fields = {}
-    if root is None:
-        root = ""
-    else:
-        root = root + sep
+    root = "" if root is None else root + sep
     for k, field in schema._declared_fields.items():
         if isinstance(field, mm.fields.Nested):
             fields.update(flatten_fields(field.nested, root=root + k))
@@ -35,6 +32,4 @@ def create_flattened_schema(BaseSchema, sep="_"):
 
     schema_name = BaseSchema.__name__ if hasattr(BaseSchema, "__name__") else BaseSchema
 
-    FlatSchema = type(f"Flat{schema_name}", (mm.Schema,), new_fields)
-
-    return FlatSchema
+    return type(f"Flat{schema_name}", (mm.Schema,), new_fields)
