@@ -1,12 +1,18 @@
 import marshmallow as mm
 from emannotationschemas.schemas.base import (
-    FlatSegmentationReferenceSinglePoint,
+    AnnotationSchema,
+    BoundSpatialPoint,
     SpatialPoint,
 )
 
 
-class NucleusDetection(FlatSegmentationReferenceSinglePoint):
+class NucleusDetection(AnnotationSchema):
     volume = mm.fields.Float(description="the volume of the nucleus detected in um^3")
+    pt = mm.fields.Nested(
+        BoundSpatialPoint,
+        required=True,
+        description="the centroid of the nucleus, to be linked to the segmentation",
+    )
     bb_start = mm.fields.Nested(
         SpatialPoint,
         required=False,
